@@ -26,8 +26,6 @@ from werkzeug._reloader import run_with_reloader
 from .namespace import Namespace
 from .test_client import SocketIOTestClient
 
-__version__ = '5.1.0'
-
 
 class _SocketIOMiddleware(socketio.WSGIApp):
     """This WSGI middleware simply exposes the Flask application in the WSGI
@@ -614,10 +612,11 @@ class SocketIO(object):
                             'ssl_version', 'ca_certs',
                             'do_handshake_on_connect', 'suppress_ragged_eofs',
                             'ciphers']
-                ssl_params = {k: kwargs[k] for k in kwargs if k in ssl_args}
+                ssl_params = {k: kwargs[k] for k in kwargs
+                              if k in ssl_args and kwargs[k] is not None}
+                for k in ssl_args:
+                    kwargs.pop(k, None)
                 if len(ssl_params) > 0:
-                    for k in ssl_params:
-                        kwargs.pop(k)
                     ssl_params['server_side'] = True  # Listening requires true
                     eventlet_socket = eventlet.wrap_ssl(eventlet_socket,
                                                         **ssl_params)
